@@ -10,27 +10,38 @@
       fname <- .grep("\\.(nc)$",ziplist,value=TRUE)
    }
    else if ((nchar(Sys.which("gzip")))&&
-            (isZip <- (isZip1 <- .lgrep("\\.gz$",fname)>0)||
+            (isZip <- (isZip1 <- .lgrep("\\.gz$",fname)>0) ||
                       (isZip2 <- file.exists(paste0(fname,".gz"))))) {
-      stop("A")
+     # print(c(isZip1=isZip1,isZip2=isZip2))
+     # stop("A")
       if (isZip1)
          fname0 <- fname
       else if (isZip2)
-         fname0 <- paste0(fname,".bz2")
-      fname <- tempfile()
-     # on.exit(file.remove(fname))
-      system2("gzip",c("-f -d -c",.dQuote(fname0)),stdout=fname)
+         fname0 <- paste0(fname,".gz")
+      if (FALSE) {
+         fname <- tempfile()
+        # on.exit(file.remove(fname))
+         system2("gzip",c("-f -d -c",.dQuote(fname0)),stdout=fname,stderr=FALSE)
+      }
+      else {
+         fname <- .ursaCacheRaster(fname0,unpack="gzip")
+      }
    }
-   else if ((nchar(Sys.which("gzip")))&&
-            (isZip <- (isZip1 <- .lgrep("\\.gz$",fname)>0)||
-                      (isZip2 <- file.exists(paste0(fname,".gz"))))) {
+   else if ((nchar(Sys.which("bzip2")))&&
+            (isZip <- (isZip1 <- .lgrep("\\.bz2$",fname)>0)||
+                      (isZip2 <- file.exists(paste0(fname,".bz2"))))) {
       if (isZip1)
          fname0 <- fname
       else if (isZip2)
          fname0 <- paste0(fname,".bz2")
-      fname <- tempfile()
-     # on.exit(file.remove(fname))
-      system2("bzip2",c("-f -d -c",.dQuote(fname0)),stdout=fname)
+      if (FALSE) {
+         fname <- tempfile()
+        # on.exit(file.remove(fname))
+         system2("bzip2",c("-f -d -c",.dQuote(fname0)),stdout=fname,stderr=FALSE)
+      }
+      else {
+         fname <- .ursaCacheRaster(fname0,unpack="bzip2")
+      }
    }
    else if (.lgrep("^(https|http|ftp)\\://",fname)) {
       fname <- .ursaCacheDownload(fname,quiet=FALSE,mode="wb")
@@ -42,8 +53,8 @@
    }
    on.exit({
       ncdf4::nc_close(nc)
-      if (isZip)
-         file.remove(fname)
+     # if (isZip)
+     #    file.remove(fname)
    })
    level0 <- level
    var0 <- var
@@ -146,15 +157,25 @@
          ziplist <- unzip(fname,exdir=tempdir());on.exit(file.remove(ziplist))
          dsn <- .grep("\\.(nc)$",ziplist,value=TRUE)
       }
-      else if ((nchar(Sys.which("gzip")))&&(isZip <- .lgrep("\\.gz$",fname)>0)) {
+      else if ((nchar(Sys.which("gzip")))&&
+               (isZip <- (isZip1 <- .lgrep("\\.gz$",fname)>0) ||
+                         (isZip2 <- file.exists(paste0(fname,".gz"))))) {
+        # print(c(isZip1=isZip1,isZip2=isZip2))
+         if (isZip1)
+            fname0 <- fname
+         else if (isZip2)
+            fname0 <- paste0(fname,".gz")
+         fname <- .ursaCacheRaster(fname0,unpack="gzip")
+      }
+      else if ((F)&&(nchar(Sys.which("gzip")))&&(isZip <- .lgrep("\\.gz$",fname)>0)) {
          fname0 <- fname
          fname <- tempfile();on.exit(file.remove(fname))
-         system2("gzip",c("-f -d -c",.dQuote(fname0)),stdout=fname)
+         system2("gzip",c("-f -d -c",.dQuote(fname0)),stdout=fname,stderr=FALSE)
       }
       else if ((nchar(Sys.which("bzip2")))&&(isZip <- .lgrep("\\.bz2$",fname)>0)) {
          fname0 <- fname
          fname <- tempfile();on.exit(file.remove(fname))
-         system2("bzip2",c("-f -d -k",.dQuote(fname0)),stdout=fname)
+         system2("bzip2",c("-f -d -k",.dQuote(fname0)),stdout=fname,stderr=FALSE)
       }
       else if (.lgrep("^(http|https|ftp)://",fname)) {
          fname <- .ursaCacheDownload(fname,mode="wb")
@@ -166,8 +187,8 @@
       }
       on.exit({
          ncdf4::nc_close(nc)
-         if (isZip)
-            file.remove(fname)
+        # if (isZip)
+        #    file.remove(fname)
       })
    }
    else
@@ -331,11 +352,14 @@
          dimnames(val6) <- list(as.character(b[[indY]]),as.character(b[[indX]]))
       }
       if (length(indT)) {
-         dimv <- dimnames(val6)
-         dima <- dim(val6)
-         val6 <- as.character(.ncdf_timeunits(val6,attr(b[[indT]],"units")))
-         dim(val6) <- dima
-         dimnames(val6) <- dimv
+         tu <- try(.ncdf_timeunits(val6,attr(b[[indT]],"units")))
+         if (!inherits(tu,"try-error")) {
+            dimv <- dimnames(val6)
+            dima <- dim(val6)
+            val6 <- as.character(tu)
+            dim(val6) <- dima
+            dimnames(val6) <- dimv
+         }
       }
      # if (length(indT))
      #    attr(val6,"time") <- b[[indT]]
@@ -426,10 +450,20 @@
       if ((length(indx))&&(length(indy))) {
          x <- b[[indx]]
          y <- b[[indy]]
+         dx <- diff(x)
+         dy <- diff(y)
+         rx <- range(dx)
+         ry <- range(dy)
+         regx <- diff(rx)/mean(dx)
+         regy <- diff(ry)/mean(dy)
+         irregular <- (regx>0.5)||(regy>0.5)
+         if (irregular) {
+            message("Irregular grid","\n   x:",round(regx,3),"   y: ",round(regy,3))
+         }
          ##~ print(sd(diff(x)))
          ##~ print(sd(diff(y)))
-         g1$resx <- mean(unique(diff(x)))
-         g1$resy <- mean(unique(diff(y)))
+         g1$resx <- mean(unique(dx))
+         g1$resy <- mean(unique(dy))
          g1$minx <- min(x)-g1$resx/2
          g1$maxx <- max(x)+g1$resx/2
          g1$miny <- min(y)-g1$resy/2
@@ -444,6 +478,10 @@
          if (TRUE)
             g1 <- with(g1,regrid(g1,setbound=c(minx,miny,maxx,maxy)
                                    ,dim=c(rows,columns)))
+         if (T & irregular) {
+            g1$seqx <- c(x)
+            g1$seqy <- c(y)
+         }
          session_grid(g1)
          con$samples <- g1$columns
          con$lines <- g1$rows
